@@ -38,7 +38,7 @@ from flask_caching.utils import get_id
 from flask_caching.utils import make_template_fragment_key  # noqa: F401
 from flask_caching.utils import wants_args
 
-__version__ = "2.0.1"
+__version__ = "2.0.2"
 
 logger = logging.getLogger(__name__)
 
@@ -193,7 +193,7 @@ class Cache:
         """Proxy function for internal cache object."""
         return self.cache.has(*args, **kwargs)
 
-    def set(self, *args, **kwargs) -> bool:
+    def set(self, *args, **kwargs) -> Optional[bool]:
         """Proxy function for internal cache object."""
         return self.cache.set(*args, **kwargs)
 
@@ -207,9 +207,9 @@ class Cache:
 
     def delete_many(self, *args, **kwargs) -> bool:
         """Proxy function for internal cache object."""
-        return self.cache.delete_many(*args, **kwargs)  # type: ignore
+        return self.cache.delete_many(*args, **kwargs)
 
-    def clear(self) -> None:
+    def clear(self) -> bool:
         """Proxy function for internal cache object."""
         return self.cache.clear()
 
@@ -363,7 +363,7 @@ class Cache:
                     if make_cache_key is not None and callable(make_cache_key):
                         cache_key = make_cache_key(*args, **kwargs)
                     else:
-                        cache_key = _make_cache_key(args, kwargs, use_request=True)
+                        cache_key = decorated_function.make_cache_key(*args, use_request=True, **kwargs)
 
                     if (
                         callable(forced_update)
@@ -430,7 +430,8 @@ class Cache:
                 for arg_name, arg in zip(argspec_args, args):
                     kwargs[arg_name] = arg
 
-                return _make_cache_key(args, kwargs, use_request=False)
+                use_request = kwargs.pop('use_request', False)
+                return _make_cache_key(args, kwargs, use_request=use_request)
 
             def _make_cache_key_query_string():
                 """Create consistent keys for query string arguments.
